	list	P=16F84, N=100

; *******************************************************************************************
; Program:	PARITY.ASM
; Author:	John Baraclough
; Last update:	2000-05-10
;
; This program is for a PIC16F84 and tests the parity check routine.
;
; *******************************************************************************************

	include	<p16f84.inc>


	cblock	0x0C

		Temp
		Count

	endc

; *******************************************************************************************

	org	0

		goto	Start


; *******************************************************************************************
; Parity check routine.
;
;	This routine calculates the parity of the data in register W. On exit all five least
;	significant bits (Wo4::Wo0) of register W are identical and reflect the parity of the
;	input data as (Wi7^Wi6^Wi5^Wi4^Wi3^Wi2^Wi1^Wi0). Bits Wo7::Wo5 are unknown and should
;	be ignored.
;
; Input: 'W' contains the data byte (Wi7::Wi0).
;
; Output: 'W' contains the parity (Wo4::Wo0).
;
; Registers: Temp
;
; Flags: None
;
; Stack usage: None
; *******************************************************************************************
ParityCheck	movwf	Temp
		swapf	Temp, F
		xorwf	Temp, W
		movwf	Temp
		rrf	Temp, F
		rrf	Temp, F
		xorwf	Temp, W
		movwf	Temp
		rrf	Temp, F
		xorwf	Temp, W
		return


; *******************************************************************************************
; Main program starts here.
;
;	First initialise the data, call 'ParityCheck' 256 times and then stop.
;
; *******************************************************************************************

Start		clrf	Count

Main		movf	Count, W
		call	ParityCheck
Break1		incfsz	Count, F
		goto	Main		; No if here

Finish		goto	Finish


	end

